@@ -187,7 +187,7 @@ class BaseExperiment:
         else:
             raise ValueError("Wrong dimension of input X.")
 
-        self.project_path = self.path + "/" + self.project_name 
+        self.project_path = f'{self.path}/{self.project_name}'   
         self.stack = [] 
         self.stack_models = stack_models
         self.stackflag = stack_models
@@ -216,8 +216,8 @@ class BaseExperiment:
 
     def update_log_path(self)->None:
         r"""Updates log path"""
-        self.exp_path = self.project_path + "/"+ self.fit_or_cv + "/" + f"random_state-{self.random_state}"
-        self.log_path = self.exp_path + "/logs"
+        self.exp_path = f'{self.project_path}/{self.fit_or_cv}/random_state-{self.random_state}'
+        self.log_path = f'{self.exp_path}/logs'
 
     def update_exp_metadata(self)->None:
         r"""Upates exp_metadata."""
@@ -227,7 +227,7 @@ class BaseExperiment:
         self.exp_metadata.update({'random state' : int(self.random_state)})
         if self.data_module:
             self.exp_metadata.update({'size of data in MB' : float(sys.getsizeof(self.X)/10**6)})
-        json_name = self.exp_path +"/exp_metadata.json" 
+        json_name = f'{self.exp_path}/exp_metadata.json' 
         with open(json_name, 'w') as fout:
             json.dump(self.exp_metadata, fout)
 
@@ -342,7 +342,7 @@ class BaseExperiment:
                     random_state=self.random_state
                 )
 
-        elif isinstance(self.model, pl.LightningModule):
+        elif isinstance(self.model, pl.LightningModule): # other lightning modules not in astrape
             batch_size = 256 if torch.cuda.is_available() else 64
             if self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
@@ -447,7 +447,7 @@ class BaseExperiment:
             if isinstance(c, TQDMProgressBar):
                 trainer.callbacks.remove(c)
                 trainer.callbacks.append(RichProgressBar())
-        self._create_folder(self.log_path+"/tensorboardlogs/"+ self.model.__class__.__name__ + "/" + self.model_metadata)
+        self._create_folder(f"{self.log_path}/tensorboardlogs/{self.model.__class__.__name__}/{self.model_metadata}")
         return trainer
 
     def fit(
@@ -497,7 +497,7 @@ class BaseExperiment:
         self.update_log_path()
         folder_dir = f"{self.log_path}/tensorboardlogs/{self.model.__class__.__name__}/{self.model_metadata}"
         self._create_folder(folder_dir)
-        version = os.listdir(folder_dir)
+        version = len(os.listdir(folder_dir))
         log_dir = f"{folder_dir}/version_{version}"
         self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
@@ -750,9 +750,9 @@ class BaseExperiment:
     ):
         pseudomodel = model_type(**hparams)
         model_metadata = self.set_model_metadata(pseudomodel, hparams)
-        ckpt_dir = self.log_path + '/checkpoints/' + model_type.__name__ + "/" + model_metadata
-        jsonlog_dir = self.log_path + '/jsonlogs/' + model_type.__name__ + "/" + model_metadata
-        tensorboard_dir = self.log_path + '/tensorboardlogs/' + model_type.__name__ + "/" + model_metadata
+        ckpt_dir = f'{self.log_path}/checkpoints/{model_type.__name__}/{model_metadata}' 
+        jsonlog_dir = f'{self.log_path}/jsonlogs/{model_type.__name__}/{model_metadata}' 
+        tensorboard_dir =  f'{self.log_path}/tensorboardlogs/{model_type.__name__}/{model_metadata}' 
         if not os.path.exists(ckpt_dir) or not os.path.exists(jsonlog_dir) or not os.path.exists(tensorboard_dir):
             return None
         
@@ -794,7 +794,7 @@ class BaseExperiment:
             :obj:LightningModule or None: The best checkpoint(or the path if fetch_only_dir is True) as per the validation metric you defined in the argument. Returns None if there are no saved checkpoints
         """
         try:
-            jsonlogdir = self.log_path + "/jsonlogs"
+            jsonlogdir = f"{self.log_path}/jsonlogs"
         except:
             logger.info("Nothing has been saved yet.")
             return None
@@ -814,7 +814,7 @@ class BaseExperiment:
             for metadata in os.listdir(model_type_dir):
                 for version in os.listdir(metadata):
                     for file in os.listdir(version):
-                        with open(model_type_dir + "/" + version + "/" + file, "r") as json_file:
+                        with open(f"{model_type_dir}/{version}/{file}", "r") as json_file:
                             logs = json.load(json_file)
                             val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
                             if best_val is None:
@@ -837,8 +837,8 @@ class BaseExperiment:
                                 best_version = version
                             info = {val_metric : best_val}
         if not fetch_only_dir:
-            ckpt_path = self.log_path + '/checkpoints/' + model_type + "/" + best_model_metadata + "/" + best_version
-            ckpt_name = ckpt_path + "/" + str(best_path).replace(".json", "")
+            ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}' 
+            ckpt_name = f'{ckpt_path}/{str(best_path).replace(".json", "")}' 
             extension_candidates = [".ckpt", ".sav"]
             for extension_type in extension_candidates:
                 ckpt = ckpt_name + extension_type
@@ -857,8 +857,8 @@ class BaseExperiment:
                 raise AssertionError
             return best_ckpt, info
         else:
-            ckpt_path = self.log_path + '/checkpoints/' + model_type + "/" + best_model_metadata + "/" + best_version
-            ckpt_name = ckpt_path + "/" +str(best_path).replace(".json", "")
+            ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}'
+            ckpt_name = f'{ckpt_path}/{str(best_path).replace(".json", "")}' 
             extension_candidates = [".ckpt", ".sav"]
             for extension_type in extension_candidates:
                 ckpt = ckpt_name + extension_type
@@ -938,7 +938,7 @@ class BaseExperiment:
 
             Metadata of a model is a string that specifies: {model type}-{hyperparameters}
         """
-        hparams_str = self._dict_to_str(hparams)
+        hparams_str = self._params_to_str(hparams)
         hparams_str = "default_hyperparameters" if hparams_str == "" else hparams_str
         
         model_metadata = f"{model.__class__.__name__}-{hparams_str}" 
@@ -966,7 +966,7 @@ class BaseExperiment:
             if len(new_metadata) > length_limit:
                 logger.info(f"The length of the metadata is too long due to long hyperparameter specs. \
                     We will take the first {length_limit-subtract} letters from the hyperparameter part.")
-                new_metadata = hparams_str[:length_limit-subtract] 
+                new_metadata = f"{model.__class__.__name__}-{hparams_str[:length_limit-subtract]}" 
 
                 model_metadata = new_metadata
         return model_metadata
@@ -1088,12 +1088,7 @@ class BaseExperiment:
         return directory
 
     @staticmethod
-    def _dict_to_str(dictionary : dict)->str:
-        r"""Polishes string form of the dictionary. Applied when defining hparams and using **hparams to pass arguments."""
-        out = str(dictionary).replace("{", "").replace("}","").replace(" ","-").replace(":","").replace("-","").replace("\n", "-").replace('"', "").replace(".","d").replace("'","")
+    def _params_to_str(dictionary : dict)->str:
+        r"""Returns a string version of passed arguments. Applied when defining hparams and using **hparams to pass arguments."""
+        out = str(dictionary).replace("{", "").replace("}","").replace(" ","-").replace(":","").replace("-","").replace("\n", "-").replace('"', "").replace(".","d").replace("'","").replace(",","_")
         return out
-
-    def _args_to_str(*args)->str:
-        r"""Polishes string form of the args when not. Applited when passing arguments as *args"""
-        out = str(args).replace(",","_")
-        return out
\ No newline at end of file
