@@ -131,9 +131,9 @@ class BaseProject:
         else:
             raise ValueError(f"Wrong dimension for input X.")
 
-        self.project_path = self.path + "/" + self.project_name
+        self.project_path = f'{self.path}/{self.project_name}' 
         self._create_folder(self.project_path)
-        self.log_dir = self.project_path + "/projectlogs"
+        self.log_dir = f'{self.project_path}/projectlogs'
         self._create_folder(self.log_dir)
         self.project_logger = SummaryWriter(log_dir=self.log_dir)
 
@@ -145,7 +145,7 @@ class BaseProject:
         self.exps = {}
         self.n_exp = 0
 
-        self._create_folder(self.project_path+"/results")
+        self._create_folder(f'{self.project_path}/results')
         for exp_name, exp in self.create_experiments(amount=1, stack_exps=False).items():
             pseudoexp = exp
         self.pseudoexp = pseudoexp # use this dummy experiement for calling Experiment methods
@@ -214,7 +214,7 @@ class BaseProject:
             self.random_states.append(seed)
             exp_parameters = {}
             exp_parameters.update(exp_common_parameters)
-            exp_parameters.update({f'random_number' : seed})
+            exp_parameters.update({'random_number' : seed})
             exp = Experiment(**exp_parameters)
             exp_name = f'random_state-{exp.random_state}'
             if stack_exps:
@@ -244,7 +244,7 @@ class BaseProject:
         """
         random_state = experiment.random_state
         if random_state in self.random_states:
-            raise ValueError(f'There is already an "Experiment" with the same random state.')
+            raise ValueError('There is already an "Experiment" with the same random state.')
         exp_name = f'random_state-{random_state}'
         self.exps.update({exp_name : experiment})
 
@@ -560,13 +560,13 @@ class BaseProject:
                 for label_idx in range(self.n_classes):
                     points_dict.update({label_idx: pca_data[self.y==label_idx]})
                     plt.scatter(x=points_dict[label_idx][:,0], y=points_dict[label_idx][:,1], label=label_idx)
-                plt.title(f'Data Distribution')
-                plt.xlabel(f'1st principal axis')
-                plt.ylabel(f'2nd principal axis')
+                plt.title('Data Distribution')
+                plt.xlabel('1st principal axis')
+                plt.ylabel('2nd principal axis')
                 plt.legend(loc=(1.,1.))
                 plt.show()
                 plt.savefig(points_dir+ f"/points_distribution_PCA.png")  
-                self.project_logger.add_figure(f'data distribution_PCA', fig)
+                self.project_logger.add_figure('data distribution_PCA', fig)
 
                 
     
@@ -574,7 +574,7 @@ class BaseProject:
 
             if len(self.dims) == 1 :
                 raise AssertionError(f"Wrong dimension {self.dims} for image data. It should be at least 2-dimensional.")
-            img_dir = self.project_path + f"/visualizations"
+            img_dir =  f"{self.project_path}/visualizations"
             self._create_folder(img_dir)
             
             if len(self.dims) == 2 : # 2D, black & white
@@ -587,7 +587,7 @@ class BaseProject:
             imgs_to_show = imgs[sampling_idx]
             labels_to_show = self.y[sampling_idx]
             # for logging
-            self.project_logger.add_images(f'sample_images', imgs_to_show, dataformats=dataformats)
+            self.project_logger.add_images('sample_images', imgs_to_show, dataformats=dataformats)
             dataformats_without_N = dataformats.replace("N","")
             for i in range(n_data):
                 self.project_logger.add_image(
@@ -606,9 +606,9 @@ class BaseProject:
                     if idx < n_data + 1:
                         img = fig.add_subplot(rows, cols, idx)
                         img.imshow(self.X[sampling_idx][idx-1])
-                        img.set_title(f'label : {labels_to_show[idx-1]}')
+                        img.set_title('label : {labels_to_show[idx-1]}')
             plt.show()
-            plt.savefig(img_dir + "/image_samples.png")       
+            plt.savefig(f"{img_dir}/image_samples.png")       
 
         elif self.domain_type == "audio":
             raise NotImplementedError("Audio data unimplemented.") # TODO: implement this
@@ -626,10 +626,10 @@ class BaseProject:
 
             list of `str`: All directories of fitted and logged ``Experiments``.
         """
-        log_base_dir = self.project_path + "/FIT"
+        log_base_dir = f"{self.project_path}/FIT"
         random_state_dir_list = []
         for random_state_dir in os.listdir(log_base_dir):
-            random_state_dir_list.append(log_base_dir + "/" + random_state_dir)
+            random_state_dir_list.append(f'{log_base_dir}/{random_state_dir}')
 
         return random_state_dir_list
 
@@ -658,12 +658,12 @@ class BaseProject:
         mode = 'min' if val_metric == 'val/loss' else 'max'
         random_state_dir_list = self.get_available_random_states()
         for random_state_dir in random_state_dir_list:
-            jsonlog_dir = random_state_dir+"/logs/jsonlogs"
+            jsonlog_dir = f"{random_state_dir}/logs/jsonlogs"
             for model_type_dir in os.listdir(jsonlog_dir): 
-                for metadata_dir in os.listdir(jsonlog_dir + "/" + model_type_dir): 
-                    for version in os.listdir(jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir): 
-                        for file in os.listdir(jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir + "/" + version): 
-                            file_path = jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir + "/" + version + "/" + file 
+                for metadata_dir in os.listdir(f'{jsonlog_dir}/{model_type_dir}'): 
+                    for version in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}'): 
+                        for file in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}/{version}'): 
+                            file_path = f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}/{version}/{file}'  
                             with open(file_path, "r") as json_file:
                                 logs = json.load(json_file)
                                 val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
@@ -723,13 +723,13 @@ class BaseProject:
         mode = 'min' if val_metric == 'val/loss' else 'max'
         random_state_dir_list = self.get_available_random_states()
         for random_state_dir in random_state_dir_list:
-            jsonlog_dir = random_state_dir+"/logs/jsonlogs"
+            jsonlog_dir = f'{random_state_dir}/logs/jsonlogs'
             for model_type_dir in os.listdir(jsonlog_dir): 
                 if str(model_type_dir) == model_type.__name__:
-                    for metadata_dir in os.listdir(jsonlog_dir + "/" + model_type_dir): 
-                        for version in os.listdir(jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir): 
-                            for file in os.listdir(jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir + "/" + version):
-                                file_path = jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir + "/" + version + "/" + file 
+                    for metadata_dir in os.listdir(f'{jsonlog_dir}/{model_type_dir}'): 
+                        for version in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}'): 
+                            for file in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}/{version}'):
+                                file_path = f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}/{version}/{file}'
                                 with open(file_path, "r") as json_file:
                                     logs = json.load(json_file)
                                     val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
@@ -843,16 +843,16 @@ class BaseProject:
 
         performances_per_metadata = {}
         for random_state_dir in random_state_dir_list:
-            jsonlog_dir = random_state_dir+"/logs/jsonlogs"
+            jsonlog_dir = f'{random_state_dir}/logs/jsonlogs'
             for model_type_dir in os.listdir(jsonlog_dir): 
-                for metadata_dir in os.listdir(jsonlog_dir + "/" + model_type_dir):
+                for metadata_dir in os.listdir(f'{jsonlog_dir}/{model_type_dir}'):
                     if metadata_dir not in metadata_list:
                         metadata_list.append(metadata_dir) 
                         performances_per_metadata.update({metadata_dir: []})
                     best_val = None
-                    for version in os.listdir(jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir): 
-                        for file in os.listdir(jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir + "/" + version): 
-                            file_path = jsonlog_dir + "/" + model_type_dir + "/" + metadata_dir + "/" + version + "/" + file 
+                    for version in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}'): 
+                        for file in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}/{version}'): 
+                            file_path = f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}/{version}/{file}' 
                             with open(file_path, "r") as json_file:
                                 logs = json.load(json_file)
                                 val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
